'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _APIError = require('../helpers/APIError');

var _APIError2 = _interopRequireDefault(_APIError);

var _httpStatus = require('http-status');

var _httpStatus2 = _interopRequireDefault(_httpStatus);

var _moment = require('moment');

var _moment2 = _interopRequireDefault(_moment);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var PERIOD_TO_INTERVAL = {
    'day': 60,
    'week': 60 * 24,
    'month': 60 * 24,
    'year': 60 * 24 * 30
};

function query(req, res, next) {

    if (!req.query.period || !PERIOD_TO_INTERVAL.hasOwnProperty(req.query.period)) {
        var err = new _APIError2.default('Period is not provided to wrong', _httpStatus2.default.BAD_REQUEST);
        return next(err);
    }

    if (!req.query.sensor) {
        var _err = new _APIError2.default('Sensor is not provided', _httpStatus2.default.BAD_REQUEST);
        return next(_err);
    }

    var _req$query = req.query,
        sensor = _req$query.sensor,
        period = _req$query.period;

    var stepMin = PERIOD_TO_INTERVAL[period];
    var from = (0, _moment2.default)();
    var to = from.clone();

    // Period
    switch (period) {
        case 'day':
            from.subtract(1, 'day');
            break;
        case 'week':
            from.subtract(7, 'day');
            break;
        case 'month':
            from.subtract(1, 'month');
            break;
        case 'year':
            from.subtract(1, 'year');
            break;
    }

    var data = [];
    var current = to.clone();

    while (current >= from) {
        data.push({
            date: current.toString(),
            value: Math.floor(Math.random() * 100)
        });
        current = current.subtract(stepMin, 'minutes');
    }

    data.reverse();

    res.json({
        from: from,
        to: to,
        sensor: sensor,
        stepMin: stepMin,
        data: data
    });
}

exports.default = { query: query };
module.exports = exports['default'];
//# sourceMappingURL=timeseries.controller.js.map
